.. _chap_usecases:

Data management use cases
=========================


.. toctree::
   :maxdepth: 1

   simple_provenance_tracking
   ../generated/examples/3rdparty_analysis_workflow
   track_data_from_webpage
